package constants

const (
	ClientConnectionAppNamePrefix       = "steampipe_client"
	ServiceConnectionAppNamePrefix      = "steampipe_service"
	ClientSystemConnectionAppNamePrefix = "steampipe_client_system"
)
